Signature

Struct Signature 

pub struct Signature { /* private fields */ }
A signature.

Implementations

Source

impl Signature

pub fn sign(secret: &SecretKey, data: &[u8]) -> Signature

Sign data using the secret key.

pub fn from_slice(sb: &[u8]) -> Result<Signature>

Return a Signature from bytes.

pub fn len(&self) -> usize

Length in bytes of the signature.

pub fn to_vec(&self) -> Vec<u8>

Convert to Vec<u8>.

pub fn buf(&self) -> &[u8]

Inner buffer as slice.

pub fn verify(&self, public: &PublicKey, data: &[u8]) -> bool

Verify the signature againt the data and the public key. Return true if the signature is valid, false otherwise.